SerialScanner class

Scans the host system for available serial ports.

Prefer FlSerial.availablePorts, which delegates here.

final ports = await SerialScanner.getAvailablePorts();
for (final p in ports) print(p);

Constructors

SerialScanner()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getAvailablePorts() Future<List<SerialPortInfo>>
Returns all serial ports currently available on this device.